% SIMULA3   Simulacin del pndulo de 3GDL.
%	MAT_Q = SIMULA3(TSIM, PINT) simula el comportamiento del pndulo
%	de 3 GDL suponiendo que no existe ningn par en ninguna de las 
%	articulaciones. TSIM indica el tiempo total de la simulacin en 
%	segundos. PINT es el	periodo de integracin en segundos. Este
%	periodo se utiliza para dividir el tiempo de simulacin en intervalos. 
%	En MAT_Q se devuelven las coordenadas articulares del robot, almacenadas 
%	por columnas, correspondientes a cada intervalo de tiempo. MAT_Q es una 
%	matriz de 3 filas y una columna por cada intervalo de simulacin.
%
%	See also WALKERORINRUNGE3.

function mat_q = simula3(tsim, pint)

% Caractersticas de la carga externa
masaext = 0;
inerciaext = zeros(3);

% Posicin y velocidad inicial de las articulaciones del robot
q  = zeros(3,1);
qp = zeros(3,1);

% Vector de tiempo dividido en intervalos
t = 0:pint:tsim;
% Nmero de intervalos + 1
n = length(t);

% Inicializacin de la matriz de coordenadas articulares
mat_q(:,1) = q;

% Se calcula las coordenadas articulares del robot
% en cada intervalo de la simulacin
for i=2:n
   % Se calcula la posicin y la velocidad de cada articulacin
   % combinando el tercer mtodo de Walker & Orin con el mtodo
   % de integracin de Runge-Kutta.
  	[q qp] = walkerorinrunge3(q,qp,zeros(3,1),t(i-1),t(i),masaext,inerciaext);

  	% Se almacenan las coordenadas articulares
  	mat_q(:,i) = q;
end
